==> commit_gen_cli-1.0.7-py3-none-any.whl: commit_gen/git_utils.py <==
"""
Git utilities for Commit-Gen.
"""

import subprocess
import sys
from typing import List, Dict, Optional, Tuple


def run_command(command: str, capture_output: bool = False) -> subprocess.CompletedProcess:
    """Run a shell command and return the result."""
    try:
        if capture_output:
            result = subprocess.run(command, shell=True, capture_output=True, text=True, check=True)
        else:
            result = subprocess.run(command, shell=True, check=True)
        return result
    except subprocess.CalledProcessError as e:
        print(f"Error running command '{command}': {e}")
        sys.exit(1)


def get_git_changes() -> str:
    """Get staged changes for commit message generation."""
    result = run_command("git diff --cached --name-status", capture_output=True)
    return result.stdout.strip()


def get_git_diff() -> str:
    """Get the diff content for commit message generation."""
    result = run_command("git diff --cached", capture_output=True)
    return result.stdout.strip()


def stage_all_changes() -> None:
    """Stage all changes in the repository."""
    run_command("git add .")


def create_git_commit(message: str) -> None:
    """Create a git commit with the given message."""
    run_command(f'git commit -m "{message}"')


def push_to_origin() -> None:
    """Push changes to the origin remote."""
    run_command("git push")


def get_current_branch() -> str:
    """Get the current git branch name."""
    result = run_command("git rev-parse --abbrev-ref HEAD", capture_output=True)
    return result.stdout.strip()


def get_last_branch_commit(branch: str) -> str:
    """Get the last commit hash of a branch."""
    result = run_command(f"git rev-parse {branch}", capture_output=True)
    return result.stdout.strip()


def get_diff_between_branches(base_commit: str, current_branch: str) -> str:
    """Get diff between two branches."""
    result = run_command(f"git diff {base_commit}..{current_branch}", capture_output=True)
    return result.stdout.strip()


def get_commits_between(base_commit: str, current_branch: str) -> str:
    """Get commits between two branches."""
    result = run_command(f"git log {base_commit}..{current_branch} --pretty=format:'%H|%an|%s'", capture_output=True)
    return result.stdout.strip()


def get_repo_url() -> Optional[str]:
    """Get the repository URL."""
    try:
        result = run_command("git config --get remote.origin.url", capture_output=True)
        url = result.stdout.strip()
        # Convert SSH URL to HTTPS if needed
        if url.startswith("git@"):
            url = url.replace("git@", "https://").replace(":", "/")
        return url
    except subprocess.CalledProcessError:
        return None


def get_commit_time(commit_hash: str) -> str:
    """Get the commit time in a readable format."""
    result = run_command(f"git show -s --format=%ci {commit_hash}", capture_output=True)
    return result.stdout.strip()


def get_modified_files() -> List[Dict[str, str]]:
    """Get list of modified and untracked files with their status."""
    files = []
    
    # Get modified files
    try:
        result = run_command("git status --porcelain", capture_output=True)
        for line in result.stdout.strip().split('\n'):
            if line.strip():
                status = line[:2].strip()
                filename = line[3:]
                
                # Parse status
                if status == 'M':
                    file_status = "modified"
                elif status == 'A':
                    file_status = "added"
                elif status == 'D':
                    file_status = "deleted"
                elif status == 'R':
                    file_status = "renamed"
                elif status == 'C':
                    file_status = "copied"
                elif status == 'U':
                    file_status = "unmerged"
                elif status == '??':
                    file_status = "untracked"
                else:
                    file_status = "unknown"
                
                files.append({
                    "filename": filename,
                    "status": file_status,
                    "full_status": status
                })
    except subprocess.CalledProcessError:
        pass
    
    return files


def get_file_info(filename: str) -> Dict[str, str]:
    """Get detailed information about a file."""
    import os
    from pathlib import Path
    
    file_path = Path(filename)
    info = {
        "filename": filename,
        "exists": file_path.exists(),
        "size": "0B",
        "last_modified": "unknown"
    }
    
    if file_path.exists():
        # Get file size
        size_bytes = file_path.stat().st_size
        if size_bytes < 1024:
            info["size"] = f"{size_bytes}B"
        elif size_bytes < 1024 * 1024:
            info["size"] = f"{size_bytes // 1024}KB"
        else:
            info["size"] = f"{size_bytes // (1024 * 1024)}MB"
        
        # Get last modified time
        mtime = file_path.stat().st_mtime
        from datetime import datetime
        info["last_modified"] = datetime.fromtimestamp(mtime).strftime("%Y-%m-%d %H:%M")
    
    return info


def stage_specific_files(filenames: List[str]) -> None:
    """Stage specific files."""
    if filenames:
        files_str = " ".join(f'"{f}"' for f in filenames)
        run_command(f"git add {files_str}")


def get_staged_files() -> List[str]:
    """Get list of currently staged files."""
    try:
        result = run_command("git diff --cached --name-only", capture_output=True)
        return [f.strip() for f in result.stdout.strip().split('\n') if f.strip()]
    except subprocess.CalledProcessError:
        return []


def clear_staging_area() -> None:
    """Clear the git staging area."""
    run_command("git reset")


def is_git_repository() -> bool:
    """Check if current directory is a git repository."""
    try:
        run_command("git rev-parse --git-dir", capture_output=True)
        return True
    except subprocess.CalledProcessError:
        return False


def get_file_category(filename: str) -> str:
    """Categorize file based on extension and path."""
    filename_lower = filename.lower()
    
    # Code files
    if any(filename_lower.endswith(ext) for ext in ['.py', '.js', '.ts', '.java', '.cpp', '.c', '.go', '.rs', '.php', '.rb']):
        return "code"
    
    # Config files
    if any(filename_lower.endswith(ext) for ext in ['.json', '.yaml', '.yml', '.toml', '.ini', '.cfg', '.conf']):
        return "config"
    
    # Documentation
    if any(filename_lower.endswith(ext) for ext in ['.md', '.txt', '.rst', '.adoc']):
        return "docs"
    
    # Tests
    if 'test' in filename_lower or 'spec' in filename_lower:
        return "tests"
    
    # Assets
    if any(filename_lower.endswith(ext) for ext in ['.png', '.jpg', '.jpeg', '.gif', '.svg', '.ico']):
        return "assets"
    
    # Build/Dependencies
    if any(filename_lower.endswith(ext) for ext in ['.lock', '.log', '.tmp', '.cache']):
        return "build"
    
    return "other"

==> commit_gen_cli-1.0.8-py3-none-any.whl: commit_gen/git_utils.py <==
"""
Git utilities for Commit-Gen.
"""

import subprocess
import sys
from typing import List, Dict, Optional, Tuple


def run_command(command: str, capture_output: bool = False) -> subprocess.CompletedProcess:
    """Run a shell command and return the result."""
    try:
        if capture_output:
            result = subprocess.run(command, shell=True, capture_output=True, text=True, check=True)
        else:
            result = subprocess.run(command, shell=True, check=True)
        return result
    except subprocess.CalledProcessError as e:
        print(f"Error running command '{command}': {e}")
        sys.exit(1)


def get_git_changes() -> str:
    """Get staged changes for commit message generation."""
    result = run_command("git diff --cached --name-status", capture_output=True)
    return result.stdout.strip()


def get_git_diff() -> str:
    """Get the diff content for commit message generation."""
    result = run_command("git diff --cached", capture_output=True)
    return result.stdout.strip()


def stage_all_changes() -> None:
    """Stage all changes in the repository."""
    run_command("git add .")


def create_git_commit(message: str) -> None:
    """Create a git commit with the given message."""
    run_command(f'git commit -m "{message}"')


def push_to_origin() -> None:
    """Push changes to the origin remote."""
    run_command("git push")


def get_current_branch() -> str:
    """Get the current git branch name."""
    result = run_command("git rev-parse --abbrev-ref HEAD", capture_output=True)
    return result.stdout.strip()


def get_last_branch_commit(branch: str) -> str:
    """Get the last commit hash of a branch."""
    result = run_command(f"git rev-parse {branch}", capture_output=True)
    return result.stdout.strip()


def get_diff_between_branches(base_commit: str, current_branch: str) -> str:
    """Get diff between two branches."""
    result = run_command(f"git diff {base_commit}..{current_branch}", capture_output=True)
    return result.stdout.strip()


def get_commits_between(base_commit: str, current_branch: str) -> str:
    """Get commits between two branches."""
    result = run_command(f"git log {base_commit}..{current_branch} --pretty=format:'%H|%an|%s'", capture_output=True)
    return result.stdout.strip()


def get_repo_url() -> Optional[str]:
    """Get the repository URL."""
    try:
        result = run_command("git config --get remote.origin.url", capture_output=True)
        url = result.stdout.strip()
        # Convert SSH URL to HTTPS if needed
        if url.startswith("git@"):
            url = url.replace("git@", "https://").replace(":", "/")
        return url
    except subprocess.CalledProcessError:
        return None


def get_commit_time(commit_hash: str) -> str:
    """Get the commit time in a readable format."""
    result = run_command(f"git show -s --format=%ci {commit_hash}", capture_output=True)
    return result.stdout.strip()


def get_modified_files() -> List[Dict[str, str]]:
    """Get list of modified and untracked files with their status."""
    files = []
    
    # Get modified files
    try:
        result = run_command("git status --porcelain", capture_output=True)
        for line in result.stdout.strip().split('\n'):
            if line.strip():
                status = line[:2].strip()
                filename = line[3:]
                
                # Skip deleted files that no longer exist
                if status == 'D':
                    continue
                
                # Check if file exists (for untracked files)
                if status == '??':
                    import os
                    if not os.path.exists(filename):
                        continue
                
                # Parse status
                if status == 'M':
                    file_status = "modified"
                elif status == 'A':
                    file_status = "added"
                elif status == 'D':
                    file_status = "deleted"
                elif status == 'R':
                    file_status = "renamed"
                elif status == 'C':
                    file_status = "copied"
                elif status == 'U':
                    file_status = "unmerged"
                elif status == '??':
                    file_status = "untracked"
                else:
                    file_status = "unknown"
                
                files.append({
                    "filename": filename,
                    "status": file_status,
                    "full_status": status
                })
    except subprocess.CalledProcessError:
        pass
    
    return files


def get_file_info(filename: str) -> Dict[str, str]:
    """Get detailed information about a file."""
    import os
    from pathlib import Path
    
    file_path = Path(filename)
    info = {
        "filename": filename,
        "exists": file_path.exists(),
        "size": "0B",
        "last_modified": "unknown"
    }
    
    if file_path.exists():
        # Get file size
        size_bytes = file_path.stat().st_size
        if size_bytes < 1024:
            info["size"] = f"{size_bytes}B"
        elif size_bytes < 1024 * 1024:
            info["size"] = f"{size_bytes // 1024}KB"
        else:
            info["size"] = f"{size_bytes // (1024 * 1024)}MB"
        
        # Get last modified time
        mtime = file_path.stat().st_mtime
        from datetime import datetime
        info["last_modified"] = datetime.fromtimestamp(mtime).strftime("%Y-%m-%d %H:%M")
    
    return info


def stage_specific_files(filenames: List[str]) -> None:
    """Stage specific files."""
    if not filenames:
        return
    
    # Filter out non-existent files
    existing_files = []
    missing_files = []
    
    for filename in filenames:
        import os
        if os.path.exists(filename):
            existing_files.append(filename)
        else:
            missing_files.append(filename)
    
    # Show warnings for missing files
    if missing_files:
        print(f"⚠️  Warning: The following files don't exist and will be skipped:")
        for file in missing_files:
            print(f"   - {file}")
    
    # Stage only existing files
    if existing_files:
        files_str = " ".join(f'"{f}"' for f in existing_files)
        try:
            run_command(f"git add {files_str}")
            print(f"✅ Successfully staged {len(existing_files)} files")
        except subprocess.CalledProcessError as e:
            print(f"❌ Error staging files: {e}")
            # Continue with commit process even if staging fails
    else:
        print("❌ No valid files to stage")


def get_staged_files() -> List[str]:
    """Get list of currently staged files."""
    try:
        result = run_command("git diff --cached --name-only", capture_output=True)
        return [f.strip() for f in result.stdout.strip().split('\n') if f.strip()]
    except subprocess.CalledProcessError:
        return []


def clear_staging_area() -> None:
    """Clear the git staging area."""
    run_command("git reset")


def is_git_repository() -> bool:
    """Check if current directory is a git repository."""
    try:
        run_command("git rev-parse --git-dir", capture_output=True)
        return True
    except subprocess.CalledProcessError:
        return False


def get_file_category(filename: str) -> str:
    """Categorize file based on extension and path."""
    filename_lower = filename.lower()
    
    # Code files
    if any(filename_lower.endswith(ext) for ext in ['.py', '.js', '.ts', '.java', '.cpp', '.c', '.go', '.rs', '.php', '.rb']):
        return "code"
    
    # Config files
    if any(filename_lower.endswith(ext) for ext in ['.json', '.yaml', '.yml', '.toml', '.ini', '.cfg', '.conf']):
        return "config"
    
    # Documentation
    if any(filename_lower.endswith(ext) for ext in ['.md', '.txt', '.rst', '.adoc']):
        return "docs"
    
    # Tests
    if 'test' in filename_lower or 'spec' in filename_lower:
        return "tests"
    
    # Assets
    if any(filename_lower.endswith(ext) for ext in ['.png', '.jpg', '.jpeg', '.gif', '.svg', '.ico']):
        return "assets"
    
    # Build/Dependencies
    if any(filename_lower.endswith(ext) for ext in ['.lock', '.log', '.tmp', '.cache']):
        return "build"
    
    return "other"
